package aql

import "errors"

// A MockService implements the query convert usecase interface (mock)
type MockService struct {
	throwError bool
}

// NewMockService creates a new query convert service (mock)
func NewMockService() *MockService {
	return &MockService{
		throwError: false,
	}
}

// ConvertQuery returns a hard coded string message (mock)
func (s *MockService) ConvertQuery(jsonMsg *[]byte) (*string, *string, error) {
	mockQuery := "Query converted"
	mockDatabaseName := "test-database"

	if !s.throwError {
		return &mockQuery, &mockDatabaseName, nil
	}
	return nil, &mockDatabaseName, errors.New("Failed to convert query")
}

// ToggleError decides whether the convert function throws an error
func (s *MockService) ToggleError() {
	s.throwError = !s.throwError
}
